/**
 * Logback: the reliable, generic, fast and flexible logging framework.
 * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
 *
 * This program and the accompanying materials are dual-licensed under
 * either the terms of the Eclipse Public License v1.0 as published by
 * the Eclipse Foundation
 *
 *   or (per the licensee's choosing)
 *
 * under the terms of the GNU Lesser General Public License version 2.1
 * as published by the Free Software Foundation.
 */
package ch.qos.logback.classic.pattern;

import org.junit.runner.RunWith;
import org.junit.runners.Suite;
import org.junit.runners.Suite.SuiteClasses;

@RunWith(Suite.class)
@SuiteClasses({ConverterTest.class,
        TargetLengthBasedClassNameAbbreviatorTest.class, MDCConverterTest.class,
        MarkerConverterTest.class, ExtendedThrowableProxyConverterTest.class,
        ThrowableProxyConverterTest.class,
        RootCauseFirstThrowableProxyConverterTest.class})
public class PackageTest {

}